@@ -45,6 +45,7 @@ StatementStatusStringType = Literal[
 StatusStringType = Literal["ABORTED", "ALL", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -77,6 +78,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
